@@ -67,6 +67,8 @@ Arnolfini.events = function ()
 	});
 }
 
+mediaShow.buttonPrevContent = "&larr;";
+mediaShow.buttonNextContent = "&rarr;";
 
 $(document).ready(function() {
 	Arnolfini.events();
