@@ -7,6 +7,18 @@ class CommonBrowserView(BrowserView):
     """
     Common utilities for all the other views
     """
+    def slideshow(self, parent):
+        """
+        Creates a slideshow with the media from parent
+        """
+        parentURL = parent.absolute_url()
+        structure = """
+        <div class="embededMediaShow">
+            <a  href="%s?recursive=true">slideshow</a>
+        </div>
+        """%parentURL
+        
+        return structure
 
 class DocumentView(CommonBrowserView):
     """'
